/**
 * An extended Turtle that can draw squares, polygons and spirals.
 * 
 * @author Malcolm Ryan 
 * @version 22 June 2012
 */
public class MyTurtle extends Turtle
{

    /**
     * Draw a square of the specified side length
     */
    public void drawSquare(int sideLength)
    {
        // put the pen down
        setPenDown(true);       
        
        // draw four sides
        move(sideLength);
        rotate(90);
        move(sideLength);
        rotate(90);
        move(sideLength);
        rotate(90);
        move(sideLength);
    }
    
    /**
     * Draw a polygon with the specified number of sides and given length.
     * Note: the number of sides must be 3 or greater.
     */
    public void drawPolygon(int numberOfSides, int sideLength)
    {
        // check if we have a legal number of sides
        if (numberOfSides < 3)
        {
            // print an error message
            System.out.println("Number of sides must be 3 or greater.");
        }
        else
        {
            // compute the angle to turn for each side.
            // we should turn a total of 360 degrees after all sides are drawn
            int angle = 360 / numberOfSides;
            
            for (int i = 0; i < numberOfSides; i++)
            {
                // draw a side, then rotate.
                move(sideLength);
                rotate(angle);
            }
        }        
    }
    
    /**
     * Draw a square spiral starting with the specified side length and spiralling inwards.
     */
    public void drawSpiral(int length)
    {
        // keep going around the loop under the side length is zero (or less)
        while (length > 0)
        {
            // draw a side
            move(length);
            rotate(90);
            // reduce the length by two
            length = length - 2;
        }
    }
}
